# 帮助 FastAPI - 获取帮助

你喜欢 **FastAPI** 吗？

您愿意去帮助 FastAPI，帮助其他用户以及作者吗？

或者你想要获得有关 **FastAPI** 的帮助？

下面是一些非常简单的方式去提供帮助（有些只需单击一两次链接）。

以及几种获取帮助的途径。

## 在 GitHub 上 Star **FastAPI** 

你可以在 GitHub 上 "star" FastAPI（点击右上角的 star 按钮）：<a href="https://github.com/tiangolo/fastapi" class="external-link" target="_blank">https://github.com/tiangolo/fastapi</a>。

通过添加 star，其他用户将会更容易发现 FastAPI，并了解已经有许多人认为它有用。

## Watch GitHub 仓库的版本发布

你可以在 GitHub 上 "watch" FastAPI（点击右上角的 watch 按钮）：<a href="https://github.com/tiangolo/fastapi" class="external-link" target="_blank">https://github.com/tiangolo/fastapi</a>。

这时你可以选择 "Releases only" 选项。

之后，只要有 **FastAPI** 的新版本（包含缺陷修复和新功能）发布，你都会（通过电子邮件）收到通知。

## 加入聊天室

<a href="https://gitter.im/tiangolo/fastapi?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge" target="_blank">
    <img src="https://badges.gitter.im/tiangolo/fastapi.svg" alt="Join the chat at https://gitter.im/tiangolo/fastapi">
</a>

加入 Gitter 上的聊天室：<a href="https://gitter.im/tiangolo/fastapi" class="external-link" target="_blank">https://gitter.im/tiangolo/fastapi</a>。

在这里你可以快速提问、帮助他人、分享想法等。

## 与作者联系

你可以联系 <a href="https://tiangolo.com" class="external-link" target="_blank">我 (Sebastián Ramírez / `tiangolo`)</a> - FastAPI 的作者。

你可以：

* <a href="https://github.com/tiangolo" class="external-link" target="_blank">在 **GitHub** 上关注我</a>。
    * 查看我创建的其他的可能对你有帮助的开源项目。
    * 关注我以了解我创建的新开源项目。
* <a href="https://twitter.com/tiangolo" class="external-link" target="_blank">在 **Twitter** 上关注我</a>。
    * 告诉我你是如何使用 FastAPI 的（我很乐意听到）。
    * 提出问题。
* <a href="https://www.linkedin.com/in/tiangolo/" class="external-link" target="_blank">在 **Linkedin** 上联系我</a>。
    * 与我交流。
    * 认可我的技能或推荐我 :)
* <a href="https://medium.com/@tiangolo" class="external-link" target="_blank">在 **Medium** 上阅读我写的文章（或关注我）</a>。
    * 阅读我创建的其他想法，文章和工具。
    * 关注我以了解我发布的新内容。

## 发布和 **FastAPI** 有关的推特

<a href="https://twitter.com/compose/tweet?text=I'm loving FastAPI because... https://github.com/tiangolo/fastapi cc @tiangolo" class="external-link" target="_blank"> 发布和 **FastAPI** 有关的推特</a> 让我和其他人知道你为什么喜欢它。

## 告诉我你正在如何使用 **FastAPI**

我很乐意听到有关 **FastAPI** 被如何使用、你喜欢它的哪一点、被投入使用的项目/公司等等信息。

你可以通过以下平台让我知道：

* <a href="https://twitter.com/compose/tweet?text=Hey @tiangolo, I'm using FastAPI at..." class="external-link" target="_blank">**Twitter**</a>。
* <a href="https://www.linkedin.com/in/tiangolo/" class="external-link" target="_blank">**Linkedin**</a>。
* <a href="https://medium.com/@tiangolo" class="external-link" target="_blank">**Medium**</a>。

## 为 FastAPI 投票

* <a href="https://www.slant.co/options/34241/~fastapi-review" class="external-link" target="_blank">在 Slant 上为 **FastAPI** 投票</a>。

## 帮助他人解决 GitHub 的 issues

你可以查看 <a href="https://github.com/tiangolo/fastapi/issues" class="external-link" target="_blank">已有的 issues</a> 并尝试帮助其他人。

## Watch GitHub 仓库

你可以在 GitHub 上 "watch" FastAPI（点击右上角的 "watch" 按钮）：<a href="https://github.com/tiangolo/fastapi" class="external-link" target="_blank">https://github.com/tiangolo/fastapi</a>。

如果你选择的是 "Watching" 而不是 "Releases only" 选项，你会在其他人创建了新的 issue 时收到通知。

然后你可以尝试帮助他们解决这些 issue。

## 创建 issue

你可以在 GitHub 仓库中 <a href="https://github.com/tiangolo/fastapi/issues/new/choose" class="external-link" target="_blank">创建一个新 issue</a> 用来：

* 报告 bug 或问题。
* 提议新的特性。
* 提问。

## 创建 Pull Request

你可以 <a href="https://github.com/tiangolo/fastapi" class="external-link" target="_blank">创建一个 Pull Request</a> 用来：

* 纠正你在文档中发现的错别字。
* 添加新的文档内容。
* 修复已有的 bug 或问题。
* 添加新的特性。

## 赞助作者

你还可以通过 <a href="https://github.com/sponsors/tiangolo" class="external-link" target="_blank">GitHub sponsors</a> 在经济上支持作者（我）。

这样你可以给我买杯咖啡☕️以示谢意😄。

---

感谢！
